/*    patchlevel.h
 *
 *    Copyright (C) 1993, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
 *    2003, 2004, 2005, 2006, 2007, 2008, 2009, by Larry Wall and others
 *
 *    You may distribute under the terms of either the GNU General Public
 *    License or the Artistic License, as specified in the README file.
 *
 */

#ifndef __PATCHLEVEL_H_INCLUDED__

/* do not adjust the whitespace! Configure expects the numbers to be
 * exactly on the third column */

#define PERL_REVISION	5		/* age */
#define PERL_VERSION	24		/* epoch */
#define PERL_SUBVERSION	4		/* generation */

/* The following numbers describe the earliest compatible version of
   Perl ("compatibility" here being defined as sufficient binary/API
   compatibility to run XS code built with the older version).
   Normally this should not change across maintenance releases.

   Note that this only refers to an out-of-the-box build.  Many non-default
   options such as usemultiplicity tend to break binary compatibility
   more often.

   This is used by Configure et al to figure out
   PERL_INC_VERSION_LIST, which lists version libraries
   to include in @INC.  See INSTALL for how this works.

   Porting/bump-perl-version will automatically set these to the version of perl
   to be released for blead releases, and to 5.X.0 for maint releases. Manually
   changing them should not be necessary.
*/
#define PERL_API_REVISION	5
#define PERL_API_VERSION	24
#define PERL_API_SUBVERSION	0
/*
   XXX Note:  The selection of non-default Configure options, such
   as -Duselonglong may invalidate these settings.  Currently, Configure
   does not adequately test for this.   A.D.  Jan 13, 2000
*/

#define __PATCHLEVEL_H_INCLUDED__
#endif

/*
	local_patches -- list of locally applied less-than-subversion patches.
	If you're distributing such a patch, please give it a name and a
	one-line description, placed just before the last NULL in the array
	below.  If your patch fixes a bug in the perlbug database, please
	mention the bugid.  If your patch *IS* dependent on a prior patch,
	please place your applied patch line after its dependencies. This
	will help tracking of patch dependencies.

	Please either use 'diff --unified=0' if your diff supports
	that or edit the hunk of the diff output which adds your patch
	to this list, to remove context lines which would give patch
	problems. For instance, if the original context diff is

	   *** patchlevel.h.orig	<date here>
	   --- patchlevel.h	<date here>
	   *** 38,43 ***
	   --- 38,44 ---
	     	,"FOO1235 - some patch"
	     	,"BAR3141 - another patch"
	     	,"BAZ2718 - and another patch"
	   + 	,"MINE001 - my new patch"
	     	,NULL
	     };

	please change it to
	   *** patchlevel.h.orig	<date here>
	   --- patchlevel.h	<date here>
	   *** 41,43 ***
	   --- 41,44 ---
	   + 	,"MINE001 - my new patch"
	     	,NULL
	     };

	(Note changes to line numbers as well as removal of context lines.)
	This will prevent patch from choking if someone has previously
	applied different patches than you.

        History has shown that nobody distributes patches that also
        modify patchlevel.h. Do it yourself. The following perl
        program can be used to add a comment to patchlevel.h:

#!perl
die "Usage: perl -x patchlevel.h comment ..." unless @ARGV;
open PLIN, "patchlevel.h" or die "Couldn't open patchlevel.h : $!";
open PLOUT, ">patchlevel.new" or die "Couldn't write on patchlevel.new : $!";
my $seen=0;
while (<PLIN>) {
    if (/\t,NULL/ and $seen) {
       while (my $c = shift @ARGV){
	    $c =~ s|\\|\\\\|g;
	    $c =~ s|"|\\"|g;
            print PLOUT qq{\t,"$c"\n};
       }
    }
    $seen++ if /local_patches\[\]/;
    print PLOUT;
}
close PLOUT or die "Couldn't close filehandle writing to patchlevel.new : $!";
close PLIN or die "Couldn't close filehandle reading from patchlevel.h : $!";
close DATA; # needed to allow unlink to work win32.
unlink "patchlevel.bak" or warn "Couldn't unlink patchlevel.bak : $!"
  if -e "patchlevel.bak";
rename "patchlevel.h", "patchlevel.bak" or
  die "Couldn't rename patchlevel.h to patchlevel.bak : $!";
rename "patchlevel.new", "patchlevel.h" or
  die "Couldn't rename patchlevel.new to patchlevel.h : $!";
__END__

Please keep empty lines below so that context diffs of this file do
not ever collect the lines belonging to local_patches() into the same
hunk.

 */

#if !defined(PERL_PATCHLEVEL_H_IMPLICIT) && !defined(LOCAL_PATCH_COUNT)
#  if defined(PERL_IS_MINIPERL)
#    define PERL_PATCHNUM "UNKNOWN-miniperl"
#    define PERL_GIT_UNPUSHED_COMMITS /*leave-this-comment*/
#  elif defined(PERL_MICRO)
#    define PERL_PATCHNUM "UNKNOWN-microperl"
#    define PERL_GIT_UNPUSHED_COMMITS /*leave-this-comment*/
#  else
#include "git_version.h"
#  endif
static const char * const local_patches[] = {
	NULL
#ifdef PERL_GIT_UNCOMMITTED_CHANGES
	,"uncommitted-changes"
#endif
	PERL_GIT_UNPUSHED_COMMITS    	/* do not remove this line */
	,"Fedora Patch1: Removes date check, Fedora/RHEL specific"
	,"Fedora Patch3: support for libdir64"
	,"Fedora Patch4: use libresolv instead of libbind"
	,"Fedora Patch5: USE_MM_LD_RUN_PATH"
	,"Fedora Patch6: Provide MM::maybe_command independently (bug #1129443)"
	,"Fedora Patch7: Dont run one io test due to random builder failures"
	,"Fedora Patch15: Define SONAME for libperl.so"
	,"Fedora Patch16: Install libperl.so to -Dshrpdir value"
	,"Fedora Patch22: Document Math::BigInt::CalcEmu requires Math::BigInt (CPAN RT#85015)"
	,"Fedora Patch26: Make *DBM_File desctructors thread-safe (RT#61912)"
	,"Fedora Patch27: Make PadlistNAMES() lvalue again (CPAN RT#101063)"
	,"Fedora Patch28: Make magic vtable writable as a work-around for Coro (CPAN RT#101063)"
	,"Fedora Patch30: Replace EU::MakeMaker dependency with EU::MM::Utils in IPC::Cmd (bug #1129443)"
	,"Fedora Patch34: Do not use unitialized memory in $h{\\const} warnings (RT#128189)"
	,"Fedora Patch36: Do not treat %: as a stash (RT#128238)"
	,"Fedora Patch37: Do not crash when inserting a non-stash into a stash (RT#128238)"
	,"Fedora Patch40: Fix a crash when vivifying a stub in a deleted package (RT#128532)"
	,"Fedora Patch41: Fix a crash in \"Subroutine redefined\" warning (RT#128257)"
	,"Fedora Petch48: Fix crash in splice (RT#129164, RT#129166, RT#129167)"
	,"Fedora Patch49: Fix string overrun in Perl_gv_fetchmethod_pvn_flags (RT#129267)"
	,"Fedora Patch50: Fix string overrun in Perl_gv_fetchmethod_pvn_flags (RT#129267)"
	,"Fedora Patch51: Fix string overrun in Perl_gv_fetchmethod_pvn_flags (RT#129267)"
	,"Fedora Patch52: Fix string overrun in Perl_gv_fetchmethod_pvn_flags (RT#129267)"
	,"Fedora Patch53: Fix string overrun in Perl_gv_fetchmethod_pvn_flags (RT#129267)"
	,"Fedora Patch54: Fix crash when matching UTF-8 string with non-UTF-8 substrings (RT#129350)"
	,"Fedora Patch55: Fix parsing perl options in shell bang line (RT#129336)"
	,"Fedora Patch56: Fix firstchar bitmap under UTF-8 with prefix optimization (RT#129950)"
	,"Fedora Patch57: Avoid infinite loop in h2xs tool if enum and type have the same name (RT130001)"
	,"Fedora Patch58: Fix stack handling when calling chdir without an argument (RT#129130)"
	,"Fedora Patch59: Fix crash in Storable when deserializing malformed code reference (RT#68348, RT#130098)"
	,"Fedora Patch60: Fix crash on explicit return from regular expression substitution (RT#130188)"
	,"Fedora Patch61: Fix assigning split() return values to an array"
	,"Fedora Patch62: Fix const correctness in hv_func.h (RT#130169)"
	,"Fedora Patch63: Fix a crash in optimized evaluation of \"or ((0) x 0))\" (RT#130247)"
	,"Fedora Patch64: Fix a memory leak in IO::Poll (RT#129788)"
	,"Fedora Patch65: Fix regular expression matching (RT#130307)"
	,"Fedora Patch66: Fix a buffer overflow in split in scalar context (RT#130262)"
	,"Fedora Patch67: Fix a heap overflow with pack \"W\" (RT129149)"
	,"Fedora Patch69: Fix a use-after-free when processing scalar variables in forms (RT#129125)"
	,"Fedora Patch70: Fix a heap overflow if invalid octal or hexadecimal number is used in transliteration expression (RT#129342)"
	,"Fedora Patch71: Fix out-of-bound read in case of unmatched regexp backreference (RT#129377)"
	,"Fedora Patch72: Fix UTF-8 string handling in & operator (RT#129287)"
	,"Fedora Patch73: Fix recreation of *:: (RT#129869)"
	,"Fedora Patch74: Fix a memory leak in B::RHE->HASH method (RT#130504)"
	,"Fedora Patch75: Fix parsing goto statements in multicalled subroutine (RT#113938)"
	,"Fedora Patch76: Fix a heap overlow in parsing $# (RT#129274)"
	,"Fedora Patch77: Adapt to zlib-1.2.11 (CPAN RT#119762)"
	,"Fedora Patch78: Fix compiler fatal warnings in Compress-Raw-Zlib (CPAN RT#120272)"
	,"Fedora Patch79: Fix a crash when compiling a regexp with impossible quantifiers (RT#130561)"
	,"Fedora Patch82: Fix a buffer overrun with format and \"use bytes\" (RT#130703)"
	,"Fedora Patch83: Fix a buffer overflow when studying some regexps repeatedly (RT#129281, RT#129061)"
	,"Fedora Patch85: Fix a heap buffer overflow when evaluating regexps with embedded code blocks from more than one source, RT#129881"
	,"Fedora Patch87: Fix a null-pointer dereference on malformed code (RT#130815)"
	,"Fedora Patch88: Fix an use-after-free in substr() that modifies a magic variable (RT#129340)"
	,"Fedora Patch89: Fix a memory leak leak in Perl_reg_named_buff_fetch() (RT#130822)"
	,"Fedora Patch90: Fix an invalid memory read when parsing a loop variable (RT#130814)"
	,"Fedora Patch94: Fix a heap-use-after-free in four-arguments substr call (RT#130624)"
	,"Fedora Patch95: Make File::Glob more resistant against degenerative matching (RT#131211)"
	,"Fedora Patch98: Fix a crash when calling a subroutine from a stash (RT#131085)"
	,"Fedora Patch99: Fix an improper cast of a negative integer to an unsigned 8-bit type (RT#131190)"
	,"Fedora Patch100: Fix cloning :via handles on thread creation (RT#131221)"
	,"Fedora Patch102: Fix glob UTF-8 flag on a glob reassignment (RT#131263)"
	,"Fedora Patch103: Fix a buffer overflow in my_atof2() (RT#131526)"
	,"Fedora Patch105: Fix handling backslashes in PATH environment variable when executing \"perl -S\" (RT#129183)"
	,"Fedora Patch106: Fix a conditional jump on uninitilized memory in re_intuit_start() (RT#131575)"
	,"Fedora Patch107: Fix spurious \"Assuming NOT a POSIX class\" warning (RT#131522)"
	,"Fedora Patch109: Fix handling attribute specification on our variables (RT#131597)"
	,"Fedora Patch110: Fix a crash when a match for inversely repeated group fails (RT#132017)"
	,"Fedora Patch111: Fix an overflow when parsing a character range with no preceding character (RT#132245)"
	,"Fedora Patch112: Fix walking symbol table for ISA in Carp"
	,"Fedora Patch113: Fix handling file names with null bytes in stat and lstat functions (RT#131895)"
	,"Fedora Patch114: Fix a crash when untying an object witout a stash"
	,"Fedora Patch115: Fix deparsing of transliterations with unprintable characters (RT#132405)"
	,"Fedora Patch116: Fix error reporting on do() on a directory (RT#125774)"
	,"Fedora Patch117: Fix stack manipulation when a lexical subroutine is defined in a do block in a member of an iteration list (RT#132442)"
	,"Fedora Patch118: Fix setting $! when statting a closed filehandle (RT#108288)"
	,"Fedora Patch119: Fix tainting of s/// with overloaded replacement (RT#115266)"
	,"Fedora Patch120: Expand system() arguments before a fork (RT#121105)"
	,"Fedora Patch123: Avoid undefined behavior when copying memory in Glob and pp_caller (RT#131746)"
	,"Fedora Patch125: Fix compatibility with libxcrypt (bug #1536752)"
	,"Fedora Patch126: Link XS modules to pthread library to fix linking with -z defs"
	,"Fedora Patch127: Fix parsing braced subscript after parentheses (RT#8045)"
	,"Fedora Patch200: Link XS modules to libperl.so with EU::CBuilder on Linux"
	,"Fedora Patch201: Link XS modules to libperl.so with EU::MM on Linux"
	,NULL
};



/* Initial space prevents this variable from being inserted in config.sh  */
#  define	LOCAL_PATCH_COUNT	\
	((int)(C_ARRAY_LENGTH(local_patches)-2))

/* the old terms of reference, add them only when explicitly included */
#define PATCHLEVEL		PERL_VERSION
#undef  SUBVERSION		/* OS/390 has a SUBVERSION in a system header */
#define SUBVERSION		PERL_SUBVERSION
#endif
